\name{cpef}
\alias{cpef}
\title{Parameter estimation of Three-Parameter Exponential Family}
\usage{
  cpef(y, hparam, apriori = c("lgamma", "normal"),
    ztrunc = FALSE,
    method = c("LA", "MH", "IS", "AQ", "AS"),
    verbose = FALSE, initrun = FALSE, start,
    control = list(), proposal = list())
}
\arguments{
  \item{y}{a numeric vector of length \code{n}.}

  \item{hparam}{a numeric vector of length \code{2} for
  \code{apriori}.}

  \item{apriori}{a character string of length \code{1} to
  specify a prior distribution; Defaults to \code{normal}.
  Alternative is \code{lgamma}.}

  \item{method}{a name of numerical method to be used for
  fitting the \code{formula} in the \code{\link{model}}.
  Five options of \code{MH}, \code{LA}, \code{IS},
  \code{AH}, \code{AS} are available. See \sQuote{Details}
  for more information.}

  \item{ztrunc}{a logical value; Is the zero truncated?;
  Defaults to \code{FALSE}.}

  \item{verbose}{a logical value; Be more verbose about the
  process by displaying messages; Defaults to
  \code{FALSE}.}

  \item{start}{a starting value for a canonical parameter
  to be fitted.}

  \item{initrun}{a logical value; Would you like to run the
  function \code{cpef} for other numerical method in order
  to have the best guess about \code{start}?}

  \item{control}{a list of parameters for controlling the
  fitting process. See \sQuote{Details}.}

  \item{proposal}{a list of parameters for controlling the
  fitting process. See \sQuote{Details}.}
}
\value{
  The list of components returned from \code{cpef} depends
  on what numerical method is employed. All input paramters
  are inherited. The commonly returned components are:

  \item{theta}{The estimated canonical parameter of length
  \code{1}.} \item{ess}{The effective sample size if
  \code{method=IS}.} \item{sratio}{The ratio of
  determinants of two hessian matrices if \code{method=LA}}
  \item{accept.rate}{The proportion of candidate samples
  that are accepted in the chain of length \code{n=2e3} if
  \code{method=MH}.}
}
\description{
  The function \code{cpef} numerically estimates a
  canonical parameter of the three-parameter exponential
  family of distributions that includes two different types
  of prior distributions (log-gamma and normal). See
  \sQuote{Details} and \cite{Lee 2013} for more
  information.
}
\details{
  The function \code{cpef} stands for a three-parameter
  exponenital family of distributions of a parameter which
  is canonically parameterized. This family of
  distributions has a conjugacy of log-gamma and normal
  priors to a (zero-truncated) Poisson sampling model.

  Numericall methods are implemented for both cases of
  \code{ztrunc=TRUE} and \code{ztrunc=FALSE} on this family
  of distributions that is a general form including both
  \code{apriori=lgamma} and \code{apriori=normal}.

  \code{LA} (Laplace approximation) is the implementation
  of that in the study \cite{Tierney, Kass, and Kadane
  1989}. The correction \code{const} defaults to \code{2e1}
  (log-scaled value).

  \code{MH} (Metropolis-Hasting algorithm) is the
  implementation of that in the study \cite{Chib and
  Greenberg 1995}. \code{nchains} and \code{nburns}
  defaults to \code{2e3} and \code{5e2}. Normal
  distribution with \code{mu=log(mean(y))} and
  \code{sigma=sd(y)} is chosen for a proposal distribution
  to generate a candidate sample.

  \code{IS} (Importance sampling) is the implementation of
  that in the study \cite{Denny 2001}. \code{ess}
  (effective sample size) is computed with an importance
  sample of size \code{n=1e3}. \code{cpef} is recursively
  used with \code{method=LA} for having the best guess for
  a mean value \code{mu} of a proposal distribution.

  \code{AS} (Analytic soluation) is available only and only
  if \code{ztrunc=FALSE} and \code{apriori=lgamma}.

  \code{AQ} (Adaptive quadrture) is the direct integration
  approach in terms of the canonical parameter \code{theta}
  using the R function \code{integrate} on infinite
  interval.
}
\examples{
\dontrun{
## try to change the options of numerical methods
cpef(y=rpois(1e5, 1), hparam=c(1,2), ztrunc=TRUE, method="LA")
}
}
\author{
  Chel Hee Lee <\email{gnustats@gmail.com}>
}
\references{
  Tierney L., Kass R. and Kadane J. (1989). ``Fully
  Exponential Laplace Approximations to Expectations and
  Variances of Nonpositive Functions.'' _Journal of the
  American Statistical Association_, *84*(407), pp.
  710-716.

  Chib S. and Greenberg E. (1995). ``Understanding the
  Metropolis-Hastings Algorithm.'' _The American
  Statistician_, *49*(4), pp. 327-335.

  Denny M. (2001). ``Introduction to importance sampling in
  rare-event simulations.'' _European Journal of Physics_,
  *22*(4), pp. 403.

  Lee (2013) ``Imprecise inferential framework'', PhD
  thesis.

  R Core Team (2013). R: A language and environment for
  statistical computing. R Foundation for Statistical
  Computing, Vienna, Austria.  URL
  \url{http://www.R-project.org/}.
}
\seealso{
  \code{\link{optim}}, \code{\link{integrate}},
  \code{\link{update}}, \code{\link{model}},
  \code{\link{iprior}}
}
\keyword{a}
\keyword{an}
\keyword{Bayesian}
\keyword{Canonical}
\keyword{distributions,}
\keyword{exponential}
\keyword{family}
\keyword{imprecise}
\keyword{log-gamma}
\keyword{model}
\keyword{normal}
\keyword{of}
\keyword{parametrization,}
\keyword{Poisson}
\keyword{prior}
\keyword{prior,}
\keyword{Three-parameter}
\keyword{with}
\keyword{Zero-truncated}
\keyword{zero-truncated}

