\name{cpef2reg}
\alias{cpef2reg}
\title{Parameter Estimation of (Zero-Truncated) Poisson Regression Model with
Multivariate Normal Prior Distributions.}
\usage{
  cpef2reg(y, X, ztrunc = FALSE,
    method = c("MH", "IS", "LA", "LAF"), xi, b, B,
    apriori = c("normal"), start, verbose = FALSE,
    initrun = FALSE, control = list(), proposal = list())
}
\arguments{
  \item{y}{a numeric vector of length \code{n}.}

  \item{X}{a model matrix of size \code{n}-by-\code{p}.}

  \item{b}{a mean vector of length \code{p} for
  \code{apriori}.}

  \item{B}{a variance-covariance matrix of size
  \code{p}-by-\code{p} for \code{apriori}.}

  \item{ztrunc}{a logical value; Defults to \code{FALSE};
  Is the zero truncated?}

  \item{method}{a name of numerical method to be used for
  fitting the \code{formula} in the \code{\link{model}}.
  Three options of \code{MH}, \code{LA}, and \code{IS} are
  available. See \sQuote{Details} for more information.}

  \item{xi}{a numeric vector of length \code{p} for
  prediction.}

  \item{verbose}{a logical value; Be more verbose about the
  process by displaying messages; Defaults to
  \code{FALSE}.}

  \item{initrun}{a logical value; Would you like to run the
  function \code{cpef} for other numerical method in order
  to have the best guess about \code{start}?}

  \item{control}{a list of parameters for controlling the
  fitting process. See \sQuote{Details}.}

  \item{proposal}{a list of parameters for controlling the
  fitting process. See \sQuote{Details}.}

  \item{start}{a list of parameters for controlling the
  fitting process. See \sQuote{Details}.}
}
\value{
  The list of components returned from \code{cpef2reg}
  depends on what numerical method is employed. All input
  paramters are inherited. The commonly returned components
  are:

  \item{theta}{The estimated canonical parameter of length
  \code{p}.} \item{ess}{The effective sample size if
  \code{method=IS}.} \item{sratio}{The ratio of
  determinants of two hessian matrices if \code{method=LA}}
  \item{accept.rate}{The proportion of candidate samples
  that are accepted in the chain of length \code{n=2e3} if
  \code{method=MH}.}
}
\description{
  The function \code{cpef2reg} estimates regression
  parameters of (zero-truncated) Poisson regression model
  with multivariate normal prior distributions. See
  \sQuote{Details}.
}
\details{
  Numericall methods are implemented for both cases of
  \code{ztrunc=TRUE} and \code{ztrunc=FALSE}.

  \code{LA} (Laplace approximation) is the implementation
  of that in the study \cite{Tierney, Kass, and Kadane
  1989}. The correction \code{const} defaults to \code{2e1}
  (log-scaled value).

  \code{MH} (Metropolis-Hasting algorithm) is the
  implementation of that in the study \cite{Chib and
  Greenberg 1995}. \code{nchains} and \code{nburns}
  defaults to \code{2e3} and \code{5e2}. Normal
  distribution with \code{mu=log(mean(y))} and
  \code{sigma=sd(y)} is chosen for a proposal distribution
  to generate a candidate sample.

  \code{IS} (Importance sampling) is the implementation of
  that in the study \cite{Denny 2001}. \code{ess}
  (effective sample size) is computed with an importance
  sample of size \code{n=1e3}. \code{cpef} is recursively
  used with \code{method=LA} for having the best guess for
  a mean value \code{mu} of a proposal distribution.
}
\note{
  Estimation with \code{method=AQ} frequently fails on the
  cases of \code{ztrunc=FALSE} and \code{ztrunc=TRUE} if
  \eqn{n<50}.

  Estimation with \code{method=LA} frequently fails on the
  case of \code{ztrunc=TRUE} if \eqn{n<5e2}.

  \code{method=MH} is the most safe choice for various
  conditions.
}
\examples{
\dontrun{
# cpef2reg
}
}
\author{
  Chel Hee Lee <\email{gnustats@gmail.com}>
}
\references{
  Tierney L., Kass R. and Kadane J. (1989). ``Fully
  Exponential Laplace Approximations to Expectations and
  Variances of Nonpositive Functions.'' _Journal of the
  American Statistical Association_, *84*(407), pp.
  710-716.

  Chib S. and Greenberg E. (1995). ``Understanding the
  Metropolis-Hastings Algorithm.'' _The American
  Statistician_, *49*(4), pp. 327-335.

  Denny M. (2001). ``Introduction to importance sampling in
  rare-event simulations.'' _European Journal of Physics_,
  *22*(4), pp. 403.

  Lee (2013) ``Imprecise inferential framework'', PhD
  thesis.
}
\seealso{
  \code{\link{optim}}, \code{\link{integrate}},
  \code{\link{update}}, \code{\link{model}},
  \code{\link{iprior}}
}
\keyword{a}
\keyword{an}
\keyword{Bayesian}
\keyword{imprecise}
\keyword{normal}
\keyword{Poisson}
\keyword{prior}
\keyword{prior,}
\keyword{regression}
\keyword{with}
\keyword{(Zero-truncated)}
\keyword{(zero-truncated)}

