\name{summary.imprecise}
\alias{summary}
\alias{summary.imprecise}
\title{Summarizing Imprecise Class Objcects}
\usage{
  \method{summary}{imprecise} (object, HT.est = FALSE,
    silent = FALSE, ...)
}
\arguments{
  \item{object}{the object of class \code{imprecise}.}

  \item{HT.est}{a logical value; Defaults to \code{FALSE}.
  Would like to see Horvitz-Thompson estimator?}

  \item{silent}{a logical value; Would like to see the
  report of progress messages (including warnings and error
  messages) generated from numerical methods that are used
  for a numerical approximation? Defaults to \code{FALSE}.}
}
\value{
  A list with the following compoentns: \item{est}{a list
  of vectors or matrices of the estimates of canonical
  parameters.} \item{N}{Horvitz-Thompson estimates if
  \code{HT.est=TRUE}} \item{mui}{Estimate of the mean
  parameter if \code{xi} is supplied.} \item{inf}{a numeric
  vector of length \code{p}, having an infimum of each
  canonical parameter.} \item{sup}{a numeric vector of
  length \code{p}, having a supremum of each canonical
  parameter.} \item{inf.idx}{an index vector corresponding
  to \code{inf} in \code{est}.} \item{sup.idx}{an index
  vector corresponding to \code{sup} in \code{est}.}
  \item{delta}{the vector of imprecision}
}
\description{
  The function \code{summary.imprecise} is the
  \code{imprecise} method of generic function
  \code{summary} which is used for producing summaries of
  the results from various model fitting functions
  performed on the imprecise inferential framework. See
  \sQuote{Details}.
}
\details{
  Object summaries depend on the option chosen in the
  \code{method}. The commonly returned object is \code{est}
  which is a collection of all Bayes estimates from the
  imprecise posterior.

  The Horvitz-Thompson estimator is the implementation of
  that in the study of \cite{Heijden 2003}.
  \code{HT.est=TRUE} is not allowed when
  \code{ztrunc=TRUE}.
}
\author{
  Chel Hee Lee <\email{gnustats@gmail.com}>
}
\references{
  Peter GM van der Heijden, Rami Bustami, Maarten JLF
  Cruyff, Godfried Engbersen and Hans C van Houwelingen
  (2003), Point and interval estimation of the population
  size using the truncated Poisson regression model,
  \emph{Statistical Modelling}, \bold{3}, pp. 305-322.

  Lee (2013) ``Imprecise inferential framework'', PhD
  thesis.

  Walley P (1991). _Statistical reasoning with imprecise
  probabilities_, series Monographs on statistics and
  applied probability. Chapman and Hall. ISBN
  9780412286605, <URL:
  http://books.google.ca/books?id=Nk9Qons1kHsC>.
}
\concept{
  imprecision, prior ignorance, prior modelling, imprecise
  prior, quantification of prior ignorance, indeterminate
  decision
}
\keyword{estimator}
\keyword{Horvitz-Thompson}
\keyword{imprecision,}

